#
# spec file for package kdiff3
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           kdiff3
Version:        1.8.2
Release:        lp152.1.4
Summary:        Code Comparison Utility
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            http://kdiff3.sourceforge.net/
Source0:        https://download.kde.org/stable/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(Qt5Core) >= 5.7.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Widgets)
Recommends:     %{name}-lang = %{version}

%description
KDiff3 is a program that:

* Compares or merges two or three text input files or directories

* Shows the differences line-by-line and character-by-character

* Provides an automatic merge facility and an integrated editor for
  solving merge conflicts

* Supports KDE's KIO framework (allows accessing ftp, sftp, fish, smb, etc.)

%lang_package

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %suse_update_desktop_file -r org.kde.kdiff3 Qt KDE Utility TextEditor X-KDE-Utilities-File
%if %{with lang}
  %find_lang %{name} %{name}.lang --with-man
  %find_lang diff_ext %{name}.lang
  %find_lang kdiff3fileitemactionplugin %{name}.lang
  %kf5_find_htmldocs
%endif
  %fdupes %{buildroot}

%files
%license COPYING
%{_kf5_applicationsdir}/org.kde.kdiff3.desktop
%{_kf5_appstreamdir}/org.kde.kdiff3.appdata.xml
%{_kf5_bindir}/kdiff3
%dir %{_kf5_iconsdir}/hicolor/256x256
%dir %{_kf5_iconsdir}/hicolor/256x256/apps
%{_kf5_iconsdir}/hicolor/*/apps/kdiff3.png
%{_kf5_iconsdir}/hicolor/scalable/apps/kdiff3.svgz
%{_kf5_kxmlguidir}/kdiff3/
%{_kf5_kxmlguidir}/kdiff3part/
%{_kf5_plugindir}/kf5/parts/
%{_kf5_plugindir}/kf5/kfileitemaction/
%{_kf5_servicesdir}/kdiff3part.desktop
%doc %lang(en) %{_kf5_mandir}/man1/kdiff3.1%{?ext_man}
%doc %lang(en) %{_kf5_htmldir}/en/kdiff3

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Mon Mar 30 2020 wbauer@tmo.at
- Update to 1.8.2:
  * Allowing editing of blank lines and don't mark newly inserted
    lines as a conflict (kde#411472)
  * Remove broken attempt to optimize drawing on horizontal scroll
  * Fix line numbers not shown. Use QString::number directly not
    through a format string. (kde#418813)
  * Correctly support "Print Current Page"
  * Don't attempt to free nullptr in SourceData::FileData::reset()
  * Make Preference dialog panes scroll-able if too large to fit on
    screen
  * Fix dialog filter on windows
  * Switch to QElapsedTime for timing avoids explicitly undefined
    behavior inside qt if time is changed
  * Fix sync mode
  * Make matching in CvsIngnoreList always honor bCaseSensitive
    setting
  * Don't use temporary with QLatin1String constructor, strange
    things will happen
  * ignore oversized cvsignore files
  * Fix '-L' parameter handling (kde#410962)
  * Restore accidentally deleted --auto option
  * Fixing missing menu items (kde#411602), also resolves a
    potential crash in MergeResultWindow::slotUpdateAvailabilities
    (kde#407745)
  * Prevent intermittent crash during reload/refresh
  * Show diff for empty/missing files (kde#410008)
  * Don't give false error when comparing empty folders
  * Close files when not in use - Fixes "Too many open files" bug
    (kde#408991)
  * Avoid crash when receiving mouse or key events during early
    startup (kde#407829)
  * Don't try to manually build url if parent is not set
  * Fix crash when canceling by using only one event loop in
    ProgressDialog
  * Don't append to already complete url
  * Fix manual url building in FileAccess::setFromUdsEntry -
    scheme should not change now
  * Fix craft install instructions for windows (kde#405918)
  * Fix crash in OptionDialog::slotApply() (kde#411586)
  * Fix crash in MergeResultWindow::slotUpdateAvailabilities
    (kde#407745)
  * Fixed redraw for horizontal scrolling (kde#407894, kde#399070)
* Sun May 19 2019 wbauer@tmo.at
- Update to 1.8.1:
  * Fix enabling of delta movement (kde#407562)
* Tue May 14 2019 wbauer@tmo.at
- Update to 1.8:
  * Ported to Qt5/KDE Frameworks 5
  * Bugfix: Show Identical files setting not applied after rescan
  * Change parameter errors to use dialog on Linux as well as
    console output
  * Don't sort twice when sorting in reverse order
  * Fix memory leak introduced in 0.9.91
  * Implement Cut/Paste
  * Don't enable "Choose C for Everything" on two way merge
  * Cleanup code
- Update package summary and description
- Run spec-cleaner
* Thu Dec  8 2016 fabian@ritter-vogt.de
- Revert kde4_runtime_requires change
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Wed Jun 24 2015 wbauer@tmo.at
- update to 0.9.98:
  * Text rendering now with QTextLayout fixes the following issues
    + Correct handling for variable width fonts.
    + Corrected display of highlighted text with Qt4.8.x on Ubuntu and Mac.
    + Improved handling of texts with both right to left and left to right languages (mixed Arabic and western texts).
    + Improved handling of Chinese and Japanese.
    + Whitespace characters are now shown as dots for spaces and arrows for tabs, and not only in differences.
  * Bugfixes.
- removed kdiff3-fix-save-relative-path.patch (included upstream)
* Fri Jul 26 2013 hrvoje.senjan@gmail.com
- BuildRequire only libkde4-devel, instead of kdebase4-workspace-devel
* Thu May  2 2013 aspiers@suse.com
- Add kdiff3-fix-save-relative-path.patch: fix saving merged
  files.  Patch is from: https://bugs.archlinux.org/task/31813
  and is already upstream.
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Tue Nov 20 2012 nico.kruber@gmail.com
- update to 0.9.97:
  * Memory usage optimized for comparison of large directories.
  * In overview for two way diff show if only one side contains text.
  * If text is selected in either input or output window use that in Find dialog.
  * Command line option --cs doesn't change the config value permanently anymore.
  * Windows 64 bit specific installer.
  * Bugfixes.
- removed libkdiff3part.so (not build anymore)
* Tue Oct 11 2011 dmueller@suse.de
- update to 0.9.96:
  * KDiff3FileItemActionPlugin : Context menu that also works in dolphin (for KDE>=4
  * Parser for preprocessor commands. (Allows single apostrophs ')
  * Fix crash on A/B-overview (infinite recursion)
  * Fix clearcase temp files not deleted problem on windows
  * KDiff3 plugin: When launching KDiff3 konqueror isn't blocked anymore
  * String corrections (Frederik Schwarzer)
  * Fixed writing to KIO.
  * Fixed white space merge default options
* Sat Sep 17 2011 toddrme2178@gmail.com
- Removed checks for obsolete openSUSE versions (fix for RPMLINT warnings)
- Added check for duplicate files (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Tue Aug 10 2010 beineri@opensuse.org
- updated tarball to fix build
* Mon Mar  8 2010 coolo@novell.com
- do not package docs in both subpackages
* Wed May 20 2009 beineri@opensuse.org
- require kdiff3-lang
* Fri Mar  6 2009 wstephenson@suse.de
- update to 0.9.95:
  * Show line end style for each file
  * Translation update
  * Bugfixes
* Fri Feb 20 2009 dmueller@suse.de
- update to 0.9.94:
  * ported to KDE4
  * various smaller fixes
* Sat Feb 14 2009 coolo@suse.de
- call kde_post_install
* Mon Nov 17 2008 stbinner@suse.de
- install translations for kdiff3 menu plugin (bnc#442527)
* Wed Jun 13 2007 stbinner@suse.de
- running fdupes makes kdiff3.rpm 348KB smaller
* Sun Apr 15 2007 stbinner@suse.de
- update to version 0.9.92:
  * KDE-Konqueror plugin: Launch KDiff3 from Konqueror.
  * Temp file names use process id in file name for several instances.
  * New File comparison mode: Trust the size and date, but use
    binary comparison if date doesn't match (unsafe)
  * Open dialog also shows current dirs in directory comparison mode.
  * New option for history merge: Max number of history entries
  * New option "Auto save and quit on merge without conflicts"
  * Several Bugfixes
* Sun Nov  5 2006 stbinner@suse.de
- update to version 0.9.91:
  * Unicode autodetection based on byte-order-mark.
  * Fix for crash after double click below last line
  * Saving of maximized window-state (Patch by Robert Vock)
  * Separated Merge-options in own tab
  * When pasting multiple lines into openfile dialog only first
    line is kept
  * Drawing in directory view fixed.
  * When specifying a separate output dir then for equal files a
    copy operation will also be offered.
* Wed May 24 2006 adrian@suse.de
- fix build for < 10.1
* Tue May 16 2006 stbinner@suse.de
- update to version 0.9.90
  * Fixed KIO-problems of type "File exists" with tempfiles.
  * Fix for manual alignment with 3 files which caused crash.
  * Preserve executable bit when overwriting an existing file.
  * Documentation and translations updated.
* Mon Apr 10 2006 stbinner@suse.de
- update to version 0.9.89
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 25 2005 stbinner@suse.de
- update to version 0.9.88 (unicode support)
* Thu Feb 17 2005 adrian@suse.de
- menu entry moved to xdg dir
* Sat Sep  4 2004 coolo@suse.de
- fixing Makefile problems
* Sat Aug 28 2004 adrian@suse.de
- initial package of version 0.9.86
